# Avajana
Avajana helps chatbot to express/emulate indirect expressions. Currently, it helps with chatbot bubbling. The bubble that happen to the other end of receipient when someone is typing.

## Get Started
```bash
$ pip install avajana
```

> Avajana (อวัจนะ) means non-verbal in Thai. 